@@ -1,6 +1,5 @@
 
-##
-##  Copyright (C) 2015 - 2016  Whit Armstrong and Dirk Eddelbuettel and John Laing
+##  Copyright (C) 2015 - 2022  Whit Armstrong and Dirk Eddelbuettel and John Laing
 ##
 ##  This file is part of Rblpapi
 ##
@@ -49,7 +48,11 @@
 ##' \code{defaultConnection}.
 ##' @param int.as.double A boolean indicating whether integer fields should
 ##' be retrieved as doubles instead. This option is a workaround for very
-##' large values which would overflow int32. Defaults to \sQuote{FALSE}
+##' large values which would overflow int32. Defaults to \sQuote{FALSE}.
+##' @param simplify A boolean indicating whether result objects that are one
+##' element lists should be altered to returned just the single inner object.
+##' Defaults to the value of the \sQuote{blpSimplify} option, with a fallback
+##' of \sQuote{TRUE} if unset ensuring prior behavior is maintained.
 ##' @return A list with as a many entries as there are entries in
 ##' \code{securities}; each list contains a object of type \code{returnAs} with one row
 ##' per observations and as many columns as entries in
@@ -89,7 +92,8 @@ bdh <- function(securities, fields, start.date, end.date=NULL,
                 include.non.trading.days=FALSE, options=NULL, overrides=NULL,
                 verbose=FALSE, returnAs=getOption("bdhType", "data.frame"), 
                 identity=defaultAuthentication(), con=defaultConnection(),
-                int.as.double=getOption("blpIntAsDouble", FALSE)) {
+                int.as.double=getOption("blpIntAsDouble", FALSE),
+                simplify=getOption("blpSimplify", TRUE)) {
     match.arg(returnAs, c("data.frame", "fts", "xts", "zoo", "data.table"))
     if (class(start.date) == "Date") {
         start.date <- format(start.date, format="%Y%m%d")
@@ -115,7 +119,7 @@ bdh <- function(securities, fields, start.date, end.date=NULL,
                   data.table = lapply(res, function(x) data.table::data.table(date = data.table::as.IDate(x[, 1]), x[, -1, drop = FALSE])),
                   res)
   
-  if (typeof(res)=="list" && length(res)==1) {
+    if (typeof(res)=="list" && length(res)==1 && simplify) {
         res <- res[[1]]
     }
     res
